/*
 * ErrorWindow.java
 *
 * Created on June 22, 2004, 5:32 PM
 *
 * This software is copyright (c) 2004 Board of Regents, University of Wisconsin.
 * All Rights Reserved.
 *
 * FILE:        $Source: /cvs_archive/cvs/validator/plugin/ErrorWindow.java,v $
 * 
 * AUTHOR:      $Author: dmaziuk $
 * DATE:        $Date: 2005/02/12 19:01:08 $
 * 
 * UPDATE HISTORY:
 * ---------------
 * $Log: ErrorWindow.java,v $
 * Revision 1.3  2005/02/12 19:01:08  dmaziuk
 * several fixes
 *
 * Revision 1.2  2004/10/28 19:39:20  dmaziuk
 * Plugin windows are now singletons
 *
 * Revision 1.1  2004/10/05 21:20:31  dmaziuk
 * added plugin
 * */

/**
 *
 * @author  dmaziuk
 */
public class ErrorWindow extends javax.swing.JPanel implements 
org.gjt.sp.jedit.EBComponent {
    /** separator -- change if message format changes! */
    private static final char SEPARATOR = ':';
    /** JEdit's view */
    private org.gjt.sp.jedit.View fView = null;
    /** true if window is floating */
    private boolean floating = true;
    /** plugin */
    private StarValidatorPlugin plugin = null;
    /** scroll pane */
    private javax.swing.JScrollPane scrollPane = null;
    /** text area */
    private javax.swing.JTextArea textArea = null;
    /** singleton instance */
    private static ErrorWindow fInstance = null;
//******************************************************************************
    /** Returns an instance of ErrorWindow.
     * @param view JEdit's view
     * @param position floating or docked
     */
    public static ErrorWindow createWindow( org.gjt.sp.jedit.View view, String position ) {
        if( fInstance == null ) fInstance = new ErrorWindow( view, position );
        return fInstance;
    } //************************************************************************
    /** Creates a new instance of ErrorWindow.
     * @param view JEdit's view
     * @param position floating or docked
     */
    private ErrorWindow( org.gjt.sp.jedit.View view, String position ) {
        fView = view;
        floating = position.equals( org.gjt.sp.jedit.gui.DockableWindowManager.FLOATING );
        plugin = (StarValidatorPlugin) org.gjt.sp.jedit.jEdit.getPlugin( StarValidatorPlugin.CLASSNAME );
        plugin.setErrorWindow( this );
// text box
        textArea = new javax.swing.JTextArea();
        textArea.setLineWrap( false );
        textArea.setEditable( false );
        textArea.setSelectionColor( java.awt.Color.RED );
        textArea.setSelectedTextColor( java.awt.Color.YELLOW );
        textArea.setSize( 300, 300 );
        textArea.addMouseListener( new java.awt.event.MouseAdapter() {
            public void mouseClicked( java.awt.event.MouseEvent evt ) {
                textAreaMouseClicked( evt );
            }
        } );
// scroll box
        scrollPane = new javax.swing.JScrollPane();
        scrollPane.setViewportView( textArea );
// add
        setLayout( new java.awt.BorderLayout() );
        add( scrollPane, java.awt.BorderLayout.CENTER );
        if( floating ) setPreferredSize( new java.awt.Dimension( 500, 300 ) );
    } //************************************************************************
    /** Returns text area.
     * @return text area
     */
    public javax.swing.JTextArea getTextArea() {
        return textArea;
    } //************************************************************************
    /** Read messages from stream and show them in text area.
     * @param in input stream
     * @throws java.io.IOException
     */
    public void showMessages( java.io.InputStream in )
    throws java.io.IOException {
        clear();
        addMessages( in );
    } //************************************************************************
    /** Read messages from stream and show them in text area.
     * @param in input stream
     * @throws java.io.IOException
     */
    public void addMessages( java.io.InputStream in )
    throws java.io.IOException {
        String line;
        java.io.BufferedReader br = new java.io.BufferedReader( new java.io.InputStreamReader( in ) );
        while( (line = br.readLine()) != null ) {
            textArea.append( line );
            textArea.append( "\n" );
        }
        br.close();
    } //************************************************************************
    /** Adds line to text area.
     * @param str string to add
     */
    public void add( String str ) {
        textArea.append( str );
        textArea.append( "\n" );
    } //************************************************************************
    /** Clears text area. */
    public void clear() {
        textArea.setText( "" );
        textArea.setSelectionStart( 0 );
        textArea.setSelectionEnd( 0 );
    } //************************************************************************
    /** Handles mouse click.
     * Highlights the error message user clicked on, extracts line number and
     * moves text cursor in JEdit's main buffer to that line.
     * @param evt mouse click event
     */
    private void textAreaMouseClicked( java.awt.event.MouseEvent evt ) {
        try {
            if( evt.getButton() == java.awt.event.MouseEvent.BUTTON1 ) {
// get text
                int pos = textArea.viewToModel( new java.awt.Point( evt.getX(), evt.getY() ) );
                int start = javax.swing.text.Utilities.getRowStart( textArea, pos );
                int end = javax.swing.text.Utilities.getRowEnd( textArea, pos );
                String txt = textArea.getDocument().getText( start, end - start );
                textArea.setSelectionStart( start );
                textArea.setSelectionEnd( end );
                textArea.requestFocus();
// extract line number
                int linestart = txt.indexOf( SEPARATOR );
                if( linestart < 0 ) return;
                int lineend = txt.indexOf( SEPARATOR, linestart + 1 );
                if( (lineend < 0) || ((lineend - linestart) < 1) ) return;
                pos = (new Integer( txt.substring( linestart + 1, lineend ) )).intValue();
// move caret to that line in JEdit's main buffer
                org.gjt.sp.jedit.Buffer buf = org.gjt.sp.jedit.jEdit.getBuffers()[0];
//            org.gjt.sp.jedit.Buffer buf;
//            if( plugin.getEntryFilename() != null )
//                buf = org.gjt.sp.jedit.jEdit.getBuffer( plugin.getEntryFilename() );
// Replace with _getBuffer() in jEdit 4.2
//                buf = org.gjt.sp.jedit.jEdit._getBuffer( plugin.getEntryFilename() );
//            else buf = org.gjt.sp.jedit.jEdit.getBuffers()[0];
//            org.gjt.sp.jedit.jEdit.getActiveView().goToBuffer( buf );
                int caretpos;
                if( pos <= 0 ) caretpos = buf.getLineStartOffset( 1 ); // count is from 1 in message
                else if( pos >= buf.getLineCount() )
                    caretpos = buf.getLineStartOffset( buf.getLineCount() );
                else caretpos = buf.getLineStartOffset( pos - 1 );
                fView.setBuffer( buf );
                fView.getTextArea().moveCaretPosition( caretpos );
                fView.getTextArea().requestFocus();
            }
        }
        catch( Exception e ) { /* ignore it */ }
    } //*************************************************************************
    /** Process EditBus message.
     * @param msg message
     */
    public void handleMessage( org.gjt.sp.jedit.EBMessage msg ) {
    } //************************************************************************
} //****************************************************************************
