/*
 * FunctionList.java
 *
 * Created on November 30, 2004, 2:07 PM
 *
 * This software is copyright (c) 2004 Board of Regents, University of Wisconsin.
 * All Rights Reserved.
 *
 * FILE:        $Source: /cvs_archive/cvs/validator/plugin/FunctionList.java,v $
 * 
 * AUTHOR:      $Author: dmaziuk $
 * DATE:        $Date: 2005/02/25 21:23:10 $
 * 
 * UPDATE HISTORY:
 * ---------------
 * $Log: FunctionList.java,v $
 * Revision 1.2  2005/02/25 21:23:10  dmaziuk
 * added new function
 *
 * Revision 1.1  2004/11/30 21:37:32  dmaziuk
 * added new class
 * */

/**
 *
 * @author  dmaziuk
 */
public class FunctionList {
    private static final boolean DEBUG = false;
    /** function object */
    class Function {
        /** category */
        public String fCat = null;
        /** name */
        public String fName = null;
        /** number */
        public int fNum = -1;
        /** description */
        public String fDescr = null;
        /** is data function */
        public boolean fData = false;
        /** is selected */
        public boolean fSel = false;
        /** constructor */
        public Function() {}
        /** returns "NUMBER : NAME" string */
        public String getLabel() {
            StringBuffer buf = new StringBuffer();
            buf.append( fNum );
            buf.append( ": " );
            buf.append( fName );
            return buf.toString();
        }
    }
    /** list */
    private java.util.List fList = null;
//******************************************************************************
    /** Creates a new instance of FunctionList */
    public FunctionList() {
        StarValidatorPlugin plugin = 
        (StarValidatorPlugin) org.gjt.sp.jedit.jEdit.getPlugin( StarValidatorPlugin.CLASSNAME );
        String tmp = plugin.getProperty( StarValidatorPlugin.KEY_FUNC_COUNT, true );
        if( tmp == null ) return;
        int numfuncs  = Integer.parseInt( tmp );
        int i;
        StringBuffer buf = new StringBuffer();
        Function f = null;
        fList = new java.util.ArrayList();
// read properties
        for( i = 0; i < numfuncs; i++ ) {
            buf.setLength( 0 );
            buf.append( StarValidatorPlugin.KEY_FUNC_NAME );
            buf.append( i );
            tmp = plugin.getProperty( buf.toString(), false );
            if( tmp == null ) continue;
            f = new Function();
            f.fName = tmp;
            f.fNum = i;
            buf.setLength( 0 );
            buf.append( StarValidatorPlugin.KEY_FUNC_CAT );
            buf.append( i );
            f.fCat = plugin.getProperty( buf.toString(), false );
            buf.setLength( 0 );
            buf.append( StarValidatorPlugin.KEY_FUNC_TIP );
            buf.append( i );
            f.fDescr = plugin.getProperty( buf.toString(), false );
            buf.setLength( 0 );
            buf.append( StarValidatorPlugin.KEY_FUNC_DATA );
            buf.append( i );
            tmp = plugin.getProperty( buf.toString(), false );
            if( (tmp != null) && (tmp.trim().toUpperCase().charAt( 0 ) == 'Y') )
                f.fData = true;
            fList.add( f );
        }
// pre-selected
        tmp = plugin.getProperty( StarValidatorPlugin.KEY_SELECTED, false );
        if( tmp == null ) return;
        String tok;
        int sel;
        java.util.StringTokenizer stk = new java.util.StringTokenizer( tmp );
        while( stk.hasMoreTokens() ) {
            tok = stk.nextToken();
            try {
                sel = Integer.parseInt( tok );
                for( i = 0; i < fList.size(); i++ )
                    if( ((Function) fList.get( i )).fNum == sel )
                        ((Function) fList.get( i )).fSel = true;
            }
            catch( NumberFormatException e ) {
                System.err.print( "Not a number: " );
                System.err.print( tok );
                System.err.print( " -- parsing " );
                System.err.println( StarValidatorPlugin.KEY_SELECTED );
            }
        }
if( DEBUG ) {
  System.err.println( "Config parsed, " + fList.size() + " functions" );
  for( i = 0; i < fList.size(); i++ ) System.err.println( ((Function)fList.get( i )).getLabel() );
}
    } //************************************************************************
    /** removes all elements from the list */
    public void clear() {
        fList.clear();
    } //************************************************************************
    /** returns function at index */
    public Function get( int index ) {
        return (Function) fList.get( index );
    } //************************************************************************
    /** returns list of functions in category */
    public Function [] get( String category ) {
        java.util.List l = new java.util.ArrayList();
        int i, j;
        Function f;
        for( i = 0; i < fList.size(); i++ ) {
            f = (Function) fList.get( i );
            if( f.fCat.equals( category ) ) l.add( f );
        }
        if( l.size() < 1 ) return null;
        Function [] rc = new Function[ l.size() ];
        for( i = 0; i < l.size(); i++ ) rc[i] = (Function) l.get( i );
        return rc;
    } //************************************************************************
    /** returns list of categories */
    public String [] getCategories() {
        java.util.List l = new java.util.ArrayList();
        int i, j;
        Function f;
        boolean found;
        for( i = 0; i < fList.size(); i++ ) {
            found = false;
            f = (Function) fList.get( i );
            for( j = 0; j < l.size(); j++ )
                if( f.fCat.equals( l.get( j ) ) ) {
                    found = true;
                    break;
                }
            if( ! found ) l.add( f.fCat );
        }
        if( l.size() < 1 ) return null;
        String [] rc = new String[ l.size() ];
        for( i = 0; i < l.size(); i++ ) rc[i] = (String) l.get( i );
        return rc;
    } //************************************************************************
}
